SHELL = /bin/bash
ifndef sysconfdir
include a2e/dirs.mk
endif
ifndef WHOAMI
include a2e/user.mk
endif
BINDIR ?= ${bindir}
SBNDIR ?= ${sbindir}
ETCDIR ?= ${sysconfdir}
TPLDIR ?= ${tmpldir}
LIBDIR ?= ${libdir}
PHPDIR ?= ${phpdir}
CGIDIR ?= ${cgidir}
LCLDIR ?= ${localedir}
OWNER ?= root
GROUP ?= root
SU_INSTALL ?= sudo install
SU_MKDIR ?= sudo mkdir -p
PERLBINS ?= $(wildcard *.pl)
SCSHBINS ?= $(wildcard *.scm)
RUBYBINS ?= $(wildcard *.rb)
BASHBINS ?= $(wildcard *.sh)
PYTHBINS ?= $(wildcard *.py)
BINS ?= ${PERLBINS} ${BASHBINS} ${RUBYBINS} ${SCSHBINS} ${PYTHBINS}

define binrgl
${BINDIR}/$(basename $(1)):	$(1)
	${SU_INSTALL} -m 755 -o ${OWNER} -g ${GROUP} $$< $$@
endef

define sbnrgl
${SBNDIR}/$(basename $(1)):	$(1)
	${SU_INSTALL} -m 755 -o ${OWNER} -g ${GROUP} $$< $$@
endef

define cgirgl
${CGIDIR}/$(basename $(1)):	$(1)
	${SU_INSTALL} -m 755 -o ${OWNER} -g ${GROUP} $$< $$@
endef

define etcrgl
${ETCDIR}/$(1):	$(1)
	${SU_INSTALL} -m 644 -o ${OWNER} -g ${GROUP} $$< $$@
endef

define tplrgl
${TPLDIR}/$(1):	$(1)
	${SU_INSTALL} -m 644 -o ${OWNER} -g ${GROUP} $$< $$@
endef

define librgl
${LIBDIR}/$(1):	$(1)
	${SU_INSTALL} -m 644 -o ${OWNER} -g ${GROUP} $$< $$@
endef

define phprgl
${PHPDIR}/$(basename $(1)).php:	$(1)
	${SU_INSTALL} -m 644 -o apache -g apache $$< $$@
endef

binobj = ${BINDIR}/$(basename $(1))
sbnobj = ${SBNDIR}/$(basename $(1))
phpobj = ${PHPDIR}/$(basename $(1)).php
cgiobj = ${CGIDIR}/$(basename $(1))
etcobj = ${ETCDIR}/$(1)
tplobj = ${TPLDIR}/$(1)
libobj = ${LIBDIR}/$(1)

BINOBJS := $(foreach bin,${BINS},$(call binobj,$(bin)))
SBNOBJS := $(foreach sbn,${SBNS},$(call sbnobj,$(sbn)))
CGIOBJS := $(foreach cgi,${CGIS},$(call cgiobj,$(cgi)))
ETCOBJS := $(foreach etc,${ETCS},$(call etcobj,$(etc)))
TPLOBJS := $(foreach tpl,${TPLS},$(call tplobj,$(tpl)))
LIBOBJS := $(foreach lib,${LIBS},$(call libobj,$(lib)))
PHPOBJS := $(foreach php,${PHPS},$(call phpobj,$(php)))


$(foreach bin,$(BINS),$(eval $(call binrgl,$(bin))))
$(foreach sbn,$(SBNS),$(eval $(call sbnrgl,$(sbn))))
$(foreach cgi,$(CGIS),$(eval $(call cgirgl,$(cgi))))
$(foreach etc,$(ETCS),$(eval $(call etcrgl,$(etc))))
$(foreach tpl,$(TPLS),$(eval $(call tplrgl,$(tpl))))
$(foreach lib,$(LIBS),$(eval $(call librgl,$(lib))))
$(foreach php,$(PHPS),$(eval $(call phprgl,$(php))))

lclobj = ${LCLDIR}/$(2)/LC_MESSAGES/$(1).mo
define lclrgl
$(1).$(2).mo:	$(1).$(2).po
	msgfmt -cfv -o $$@ $$<
$(call lclobj,$(1),$(2)):	$(1).$(2).mo
	${SU_INSTALL} -m 644 $$< $$@
endef
$(foreach bin,${BINS} ${SBNS},$(foreach lcl,${LCLS},$(eval $(call lclrgl,$(basename $(bin)),$(lcl)))))
lclobjs = $(foreach bin,$(1),$(foreach lcl,$(2),$(call lclobj,$(basename $(bin)),$(lcl))))
LCLOBJS := $(lclobjs ${BINS} ${SBNS},${LCLS})

DIRS := ${BINDIR} ${SBNDIR} ${PHPDIR} ${CGIDIR} ${LIBDIR} ${ETCDIR} ${TPLDIR} ${LCLDIR}
OBJS := ${BINOBJS} ${SBNOBJS} ${PHPOBJS} ${CGIOBJS} ${LIBOBJS} ${ETCOBJS} ${TPLOBJS} ${LCLOBJS}

${DIRS}:
	sudo mkdir -p $@

.PHONY:	pre_install uninstall subdirs_test install_lern
ifdef ADMINP
install:	pre_install ${DIRS} ${OBJS} ${INSTALL_EXTRA} ${EXTRA_INSTALL} post_install
	for DIR in $(strip ${SUBDIRS});do if test -d $$DIR;then $(MAKE) -C $$DIR install;fi;done
rinstall:	install
	svn commit -m "make rinstall ${DOK}"
	ssh a2e.de make -C `dokdir` install
uninstall:	pre_uninstall
	sudo rm -f ${OBJS}
	for DIR in $(strip ${SUBDIRS});do if test -d $$DIR;then $(MAKE) -C $$DIR uninstall;fi;done
endif
pre_install:	${PRE_INSTALL}

subdirs_test:
	for DIR in ${SUBDIRS};do if test -d $$DIR;then $(MAKE) -C $$DIR test;fi;done
install_lern:
	@echo WHOAMI: ${WHOAMI}
	@echo ADMINP: ${ADMINP}
	@echo OBJS: ${OBJS}
	@echo ETCDIR: ${ETCDIR}
	@echo sysconfdir: ${sysconfdir}
	@echo ETCOBJS: ${ETCOBJS}
# Local Variables:
# coding: utf-8 ;
# mode: makefile ;
# srcfile: /adv/mktdir/include/install.mk ;
# End:
