# -*- coding: utf-8; mode: makefile; srcfile: /adv/mktdir/include/rpm.mk -*-

SHELL = /bin/bash -O nullglob
ifndef ZYPPER_HOSTS
include a2e/site_makefile_cache.mk
endif
ifndef PAK
include PAK.mk
endif
PAK ?= nopackage
PAK := $(strip ${PAK})
VER ?= 0.0.1
VER := $(strip ${VER})
ifndef ARCH
ARCH := ${OSARCH}
endif
REL ?= 1
SPEC ?= ${PAK}.spec
PAV ?= ${PAK}-${VER}
REPO ?= a2e
REPOS = pvt a2e bas ext
REPODIR := /repo
NOVDIR = /repo/nov
EDITOR = edit
BATCH ?= 1
BUILD_RPMS := $(shell echo $(foreach repo,${REPOS},${REPODIR}/$(repo)) | sed -e 's| |:|g')
PAKSDIR = /var/tmp/build-root/usr/src/packages
RPMSDIR := ${PAKSDIR}/RPMS
SRPMSDIR := ${PAKSDIR}/SRPMS
VRL := ${VER}-${REL}
.PHONY: pack rmgz build rebuild srpm rpm repo install all files frepl tar rmrpm fresh
ifndef TMPL_OBJS
${SPEC}.vars:
	echo -e "include a2e/spec.mk\ninclude PAK.mk\ninclude a2e/dirs.mk" > $@
${SPEC}:	 ${SPEC}.vars ${SPEC}.tmpl
	tmplfil -o $@ --tf $^
endif
build:	${SPEC}
	BATCH=${BATCH};OPTS=${BUILD_OPTS};until { test $$BATCH == 1 || ${EDITOR} ${SPEC}.tmpl; } && tmplfil -o ${SPEC} --tf ${SPEC}.vars ${SPEC}.tmpl && $(MAKE) tbz && { sudo build --arch ${BUILD_ARCHS} --dist ${BUILD_DIST} --rpms ${BUILD_RPMS} ${REPO_ARGS} $$OPTS ${SPEC};echo $$?; } | tee ${PAK}-build.log;ERR=$$(tail -n 1 ${PAK}-build.log);test $$ERR == 0;do echo ERROR $$ERR;BATCH=0;echo ${BUILD_OPTS} | grep -qw init || OPTS='--no-init';done;
#	echo svn_add_commit ${PAK}-build.log
rebuild:
	sudo script -c "build --rpms ${BUILD_RPMS} ${SPEC}" ${PAK}-build.log
${SPEC}:	${SPEC}.tmpl
	tmplfil -o $@ --tf ${SPEC}.vars $<
${SRPMSDIR}/${PAV}-${REL}.src.rpm ${RPMSDIR}/${ARCH}/${PAV}-${REL}.${ARCH}.rpm:	${SPEC}
	sudo build --rpms ${BUILD_RPMS} ${SPEC}
${REPODIR}/${REPO}/src/${PAV}-${REL}.src.rpm:	${SRPMSDIR}/${PAV}-${REL}.src.rpm
	sudo rm -fv $@
	cp -v $< $@
define pak_cp_regl
${REPODIR}/${REPO}/${2}/${1}-${VRL}.${2}.rpm:	${RPMSDIR}/${2}/${1}-${VRL}.${2}.rpm
	sudo rm -fv $$@
	cp -v $$< $$@
	shopt -s nullglob;for F in ${RPMSDIR}/${2}/${1}-debug*-${VRL}.${2}.rpm;do cp -v $$$$F ${REPODIR}/${REPO}/${2}/;done
endef
define subpak_cp_regl
${REPODIR}/${REPO}/${2}/${PAK}-${1}-${VRL}.${2}.rpm:	${RPMSDIR}/${2}/${PAK}-${1}-${VRL}.${2}.rpm
	sudo rm -fv $$@
	cp -v $$< $$@
	shopt -s nullglob;for F in ${RPMSDIR}/${2}/${PAK}-${1}-debug*-${VRL}.${2}.rpm;do cp -v $$$$F ${REPODIR}/${REPO}/${2}/;done
endef
$(eval $(call pak_cp_regl,${PAK},${ARCH}))
$(foreach pak,${NOMPAKS_OSARCH},$(eval $(call pak_cp_regl,${pak},${OSARCH})))
$(foreach sub,${SUBPAKS_OSARCH},$(eval $(call subpak_cp_regl,${sub},${OSARCH})))
$(foreach pak,${NOMPAKS_NOARCH},$(eval $(call pak_cp_regl,${pak},noarch)))
$(foreach sub,${SUBPAKS_NOARCH},$(eval $(call subpak_cp_regl,${sub},noarch)))
rmrpm:
	rm -fv ${REPODIR}/${REPO}/src/${PAV}-${REL}.src.rpm
	for SUB in ${SUBPAKS};do rm -fv ${REPODIR}/${REPO}/${ARCH}/${PAK}-$$SUB-${VRL}.${ARCH}.rpm;done
	for SUB in ${SUBPAKS_NOARCH};do rm -fv ${REPODIR}/${REPO}/noarch/${PAK}-$$SUB-${VRL}.noarch.rpm;done
${PAK}.src.rpm:	${REPODIR}/${REPO}/src/${PAV}-${REL}.src.rpm
	rm -f $@ && ln -s $< $@ && svn_add_commit $@
define pak_ln_regl
${1}.${2}.rpm:	${REPODIR}/${REPO}/${2}/${1}-${VRL}.${2}.rpm
	rm -fv $$@
	ln -s $$< $$@
	svn_add_commit $$@
endef
define subpak_ln_regl
${PAK}-${1}.${2}.rpm:	${REPODIR}/${REPO}/${2}/${PAK}-${1}-${VRL}.${2}.rpm
	rm -fv $$@
	ln -s $$< $$@
	svn_add_commit $$@
endef
$(eval $(call pak_ln_regl,${PAK},${ARCH}))
$(foreach pak,${PAKS},$(eval $(call pak_ln_regl,${pak},${ARCH})))
$(foreach sub,${SUBPAKS},$(eval $(call subpak_ln_regl,${sub},${ARCH})))
$(foreach pak,${NOMPAKS_NOARCH},$(eval $(call pak_ln_regl,${pak},noarch)))
$(foreach sub,${SUBPAKS_NOARCH},$(eval $(call subpak_ln_regl,${sub},noarch)))
ALL_TARGETS := ${PAK}.src.rpm ${PAK}.${ARCH}.rpm $(foreach pak,${PAKS},${pak}.${ARCH}.rpm) $(foreach pak,${NOMPAKS_NOARCH},${pak}.noarch.rpm) $(foreach sub,${SUBPAKS},${PAK}-${sub}.${ARCH}.rpm) $(foreach sub,${SUBPAKS_NOARCH},${PAK}-${sub}.noarch.rpm)
all:	${ALL_TARGETS}
repo:	all
	$(MAKE) -C ${REPODIR}/${REPO} install
	mkdir -p $(foreach host,${ZYPPER_HOSTS},${NOVDIR}/${OSVER}/${ARCH}/${host})
	touch $(foreach host,${ZYPPER_HOSTS},${NOVDIR}/${OSVER}/${ARCH}/${host}/${PAK})
install:	repo
	sudo zypper install ${PAK}
rlern:
	@echo OSVER: ${OSVER}
	@echo REPO: ${REPO}
	@echo REPOS: ${REPOS} 	
	@echo REPODIR: ${REPODIR} 	
	@echo NOMPAKS_OSARCH: ${NOMPAKS_OSARCH}
	@echo SUBPAKS_OSARCH: ${SUBPAKS_OSARCH}
	@echo NOMPAKS_NOARCH: ${NOMPAKS_NOARCH}
	@echo SUBPAKS_NOARCH: ${SUBPAKS_NOARCH}
	@echo ALL_TARGETS: ${ALL_TARGETS}
#EOF
