# -*- coding: utf-8; mode: makefile; srcfile: /adv/mktdir/include/srpm.mk -*-
# rules for building opensuse rpm packages from existing source rpm packages
# used e.g. in 
# /adv/pak/perl-Variable-Magic/Makefile
# /adv/pak/perl-macros/Makefile
# /adv/pak/php5-pear-db/Makefile
# /adv/pak/perl-B-Hooks-EndOfScope
# Main targets for invocation are:
# 	make rpm -- build the rpm files and install them in the repository
#	make spec -- extract the spec file; needed if BLDSPEC is set i.e. if we build from spec rather than srpm
#	make orig -- download the srpm file; if ZYPREPO is set, download from a repository 
#	make repo -- create repository metadata after 'rpm' is completed

SHELL = /bin/bash -O nullglob
ifndef VER
include PAK.mk
endif
BAS ?= Variable-Magic
ifndef PAK
PAK := perl-${BAS}
endif
ifndef OSARCH
include a2e/site_makefile_cache.mk
endif
ifndef ARCH
ARCH := ${OSARCH}
endif
ifndef BLDSPEC
BLDSPEC := $(shell if test -r ${PAK}.spec;then echo 1;fi)
endif

.PHONY:	orig spec rpm repo rmrpm

VRL := ${VER}-${REL}
PAKDIR = /var/tmp/build-root/usr/src/packages
RPMSDIR := ${PAKDIR}/RPMS
REPDIR = /repo/suse
ZYPDIR = /var/cache/zypp/packages
REPSRPM := ${REPDIR}/ext/src/${PAK}-${VRL}.src.rpm
PAKSPEC := ${PAKDIR}/SOURCES/${PAK}.spec
PAKSRPM := ${PAKDIR}/SRPMS/${PAK}-${VRL}.src.rpm
PAKRPMS := $(if ${ARCH},${PAKDIR}/RPMS/${ARCH}/${PAK}-${VRL}.${ARCH}.rpm) $(foreach pak,${NOMPAKS_OSARCH},${PAKDIR}/ext/${OSARCH}/${pak}-${VRL}.${OSARCH}.rpm) $(foreach pak,${NOMPAKS_NOARCH},${PAKDIR}/ext/noarch/${pak}-${VRL}.noarch.rpm) $(foreach sub,${SUBPAKS_OSARCH},${PAKDIR}/ext/${OSARCH}/${PAK}-${sub}-${VRL}.${OSARCH}.rpm) $(foreach sub,${SUBPAKS_NOARCH},${PAKDIR}/ext/noarch/${PAK}-${sub}-${VRL}.noarch.rpm)
REPRPMS := $(if ${ARCH},${REPDIR}/ext/${ARCH}/${PAK}-${VRL}.${ARCH}.rpm) $(foreach pak,${NOMPAKS_OSARCH},${REPDIR}/ext/${OSARCH}/${pak}-${VRL}.${OSARCH}.rpm) $(foreach pak,${NOMPAKS_NOARCH},${REPDIR}/ext/noarch/${pak}-${VRL}.noarch.rpm) $(foreach sub,${SUBPAKS_OSARCH},${REPDIR}/ext/${OSARCH}/${PAK}-${sub}-${VRL}.${OSARCH}.rpm) $(foreach sub,${SUBPAKS_NOARCH},${REPDIR}/ext/noarch/${PAK}-${sub}-${VRL}.noarch.rpm)

ifdef ZYPREPO
${ZYPDIR}/${ZYPREPO}/src/${PAK}-${VRL}.src.rpm:
	sudo zypper mr -e ${ZYPREPO}
	sudo zypper source-install -r ${ZYPREPO} ${PAK}
	sudo zypper mr -d ${ZYPREPO}
/ul/src/${PAK}-${VRL}.src.rpm:	${ZYPDIR}/${ZYPREPO}/src/${PAK}-${VRL}.src.rpm
	cp -vf $< $@
else
/ul/src/${PAK}-${VRL}.src.rpm:
	mv -vf ~/Downloads/${PAK}-${VRL}.src.rpm /ul/src/
endif

orig:	/ul/src/${PAK}-${VRL}.src.rpm

spec:	${PAK}.spec
	! grep '^%package' $<
	grep -A 8 '%description' $<

ifndef BLDSPEC
${PAKSRPM} ${PAKRPMS} ${PAKSPEC}:	/ul/src/${PAK}-${VRL}.src.rpm
	sudo rm -fr ${PAKDIR}/SOURCES/*
	sudo build --arch ${OSARCH} --dist 11.3-${OSARCH} --rpms ${REPDIR}/pvt:${REPDIR}/a2e:${REPDIR}/bas:${REPDIR}/ext $<
${PAK}.spec:	${PAKSPEC}
	cp -v $< $@
	cp -v $@ $@.${OSVER}
	svn add $@ $@.${OSVER}
	for F in ${PAKDIR}/SOURCES/*;do B=`basename $$F`;test -e $$B || { file $$F | grep -iw text && cp -vf $$F . && svn add $$B; } || { cp -vf $$F /ul/src && ln -vs /ul/src/$$B . && svn add $$B; };done;
else
${PAKSRPM} ${PAKRPMS}:	${PAK}.spec PAK.mk
	sudo rm -fr ${PAKDIR}/SOURCES/*
	sudo build --arch ${OSARCH} --dist 11.3-${OSARCH} --rpms ${REPDIR}/pvt:${REPDIR}/a2e:${REPDIR}/bas:${REPDIR}/ext ${PAK}.spec
endif



define cp_pak_rep
${2}:	${1}	
	sudo rm -fv $$@
	cp -v $$< $$@
endef
$(eval $(call cp_pak_rep,${PAKSRPM},${REPSRPM}))
ifdef ARCH
$(eval $(call cp_pak_rep,${PAKDIR}/RPMS/${ARCH}/${PAK}-${VRL}.${ARCH}.rpm,${REPDIR}/ext/${ARCH}/${PAK}-${VRL}.${ARCH}.rpm))
endif
$(foreach pak,${NOMPAKS_OSARCH},$(eval $(call cp_pak_rep,${PAKDIR}/ext/${OSARCH}/${pak}-${VRL}.${OSARCH}.rpm,${REPDIR}/ext/${OSARCH}/${pak}-${VRL}.${OSARCH}.rpm)))
$(foreach pak,${NOMPAKS_NOARCH},$(eval $(call cp_pak_rep,${PAKDIR}/ext/noarch/${pak}-${VRL}.noarch.rpm,${REPDIR}/ext/noarch/${pak}-${VRL}.noarch.rpm)))
$(foreach sub,${SUBPAKS_OSARCH},$(eval $(call cp_pak_rep,${PAKDIR}/ext/${OSARCH}/${PAK}-${sub}-${VRL}.${OSARCH}.rpm,${REPDIR}/ext/${OSARCH}/${PAK}-${sub}-${VRL}.${OSARCH}.rpm)))
$(foreach sub,${SUBPAKS_NOARCH},$(eval $(call cp_pak_rep,${PAKDIR}/ext/noarch/${PAK}-${sub}-${VRL}.noarch.rpm,${REPDIR}/ext/noarch/${PAK}-${sub}-${VRL}.noarch.rpm)))

rpm:	${REPSRPM} ${REPRPMS}

rmrpm:
	rm -fv ${REPSRPM} ${REPRPMS}

${REPDIR}/ext/repodata/repomd.xml:	${REPSRPM} ${REPRPMS}
	cd ${REPDIR}/ext && make install
repo:	${REPDIR}/ext/repodata/repomd.xml

#EOF

